# Phylotree Viewer Module

## Overview
The Phylotree Viewer module enables the visualization of phylogenetic trees directly in Drupal. It leverages the Phylotree.js library for rendering and provides an intuitive interface for working with phylogenetic data.

## Features
- Interactive visualization of phylogenetic trees.
- Seamless integration with Drupal's field and content management.
- Configurable external library support.

## Requirements
- Drupal 10.x
- PHP 8.1 or higher
- External JavaScript libraries (Phylotree.js, D3.js v3.5.17, jQuery, Underscore.js)

## Installation
1. Download and install the module in your Drupal installation:
   ```bash
   composer require drupal/phylotree_viewer
   ```
2. Enable the module via the Drupal UI or Drush:
   ```bash
   drush en phylotree_viewer
   ```

## Required External Library Setup
1. Download the latest release of Phylotree.js from [https://github.com/veg/phylotree.js/releases](https://github.com/veg/phylotree.js/releases).
2. Download version 3.5.17 of D3.js from [https://github.com/d3/d3/releases/tag/v3.5.17](https://github.com/d3/d3/releases/tag/v3.5.17). **Note:** The Phylotree library is not compatible with newer versions of D3.js. For more information, see [this issue](https://github.com/veg/phylotree.js/issues/44).
3. Download the latest production version of jQuery from [https://jquery.com/download/](https://jquery.com/download/).
4. Download the latest production version of Underscore.js from [https://underscorejs.org/](https://underscorejs.org/).
5. Move the required files to the following locations in your module's directory:
   - **CSS:** Place `phylotree.css` in `libraries/css/`.
   - **JS:** Place `d3.min.js`, `jquery.min.js`, `phylotree.js`, and `underscore.min.js` in `libraries/js/`.
6. Navigate to **Phylotree Viewer Configurations** in the Drupal admin interface.
7. Click the **Test Libraries** button to verify that all required libraries are properly installed.

## Configuration
1. Navigate to the **Manage Display** tab of the content type containing the tree data field.
2. Select the "Phylotree Viewer" option for the field formatter.
3. Adjust configuration options as necessary for your use case.

## Usage
Once configured, the module will render phylogenetic trees interactively within your Drupal site. Ensure that all external libraries are correctly installed for optimal performance.

## Contributing
Contributions are welcome! Feel free to open issues or submit pull requests to improve this module.

## License
This project is licensed under the GPL-2.0-or-later license. See the LICENSE file for details.

